# Mojentic

Mojentic is an agentic framework that aims to provide a simple and flexible way to assemble teams of agents to solve
complex problems. Design goals are to be asynchronous with a pubsub messaging architecture.

Visit [the documentation](https://mojility.github.io/mojentic/) for more.

This code is under heavy development, and will change often. It is not recommended for production use at this time.

This code is Copyright 2025 Mojility, Inc. and is freely provided under the terms of the [MIT license](LICENSE.md).